@@ -97,6 +97,13 @@ struct fio_file {
 	uint64_t first_write;
 	uint64_t last_write;
 
+	/*
+	 * Tracks the last iodepth number of completed writes, if data
+	 * verification is enabled
+	 */
+	uint64_t *last_write_comp;
+	unsigned int last_write_idx;
+
 	/*
 	 * For use by the io engine
 	 */
